@@ -2,7 +2,7 @@ import logging
 import pathlib
 import typing
 from copy import deepcopy
-from typing import Union, Optional, List, Sequence, overload, BinaryIO, Iterable
+from typing import BinaryIO, Iterable, List, Optional, Sequence, Union, overload
 
 import numpy as np
 
@@ -10,8 +10,8 @@ from . import errors
 from .compression import LazBackend
 from .header import LasHeader
 from .laswriter import LasWriter
-from .point import record, dims, ExtraBytesParams, PointFormat
-from .point.dims import ScaledArrayView, SubFieldView, OLD_LASPY_NAMES
+from .point import ExtraBytesParams, PointFormat, dims, record
+from .point.dims import OLD_LASPY_NAMES, ScaledArrayView, SubFieldView
 from .point.record import DimensionNameValidity
 from .vlrs.vlrlist import VLRList
 
@@ -76,7 +76,7 @@ class LasData:
         2
         >>> xyz.shape
         (1065, 3)
-        >>> np.all(xyz[..., 0] == las.x)
+        >>> bool(np.all(xyz[..., 0] == las.x))
         True
         """
         return np.vstack((self.x, self.y, self.z)).transpose()
