@@ -1,14 +1,15 @@
 """ 'Entry point' of the library, Contains the various functions meant to be
 used directly by a user
 """
+
 import copy
 import io
 import logging
 import os
 from pathlib import Path
-from typing import Union, Optional
+from typing import Optional, Union
 
-from .compression import LazBackend, DecompressionSelection
+from .compression import DecompressionSelection, LazBackend
 from .errors import LaspyException
 from .header import LasHeader, Version
 from .lasappender import LasAppender
@@ -16,7 +17,7 @@ from .lasdata import LasData
 from .lasmmap import LasMMAP
 from .lasreader import LasReader
 from .laswriter import LasWriter
-from .point import dims, record, PointFormat
+from .point import PointFormat, dims, record
 from .vlrs.vlrlist import VLRList
 
 logger = logging.getLogger(__name__)
@@ -143,13 +144,18 @@ def open_las(
             stream = io.BytesIO(source)
         else:
             stream = source
-        return LasReader(
-            stream,
-            closefd=closefd,
-            laz_backend=laz_backend,
-            read_evlrs=read_evlrs,
-            decompression_selection=decompression_selection,
-        )
+        try:
+            return LasReader(
+                stream,
+                closefd=closefd,
+                laz_backend=laz_backend,
+                read_evlrs=read_evlrs,
+                decompression_selection=decompression_selection,
+            )
+        except:
+            if closefd:
+                stream.close()
+            raise
     elif mode == "w":
         if header is None:
             raise ValueError("A header is needed when opening a file for writing")
@@ -164,14 +170,19 @@ def open_las(
             assert source.seekable()
             stream = source
 
-        return LasWriter(
-            stream,
-            header=header,
-            do_compress=do_compress,
-            laz_backend=laz_backend,
-            closefd=closefd,
-            encoding_errors=encoding_errors,
-        )
+        try:
+            return LasWriter(
+                stream,
+                header=header,
+                do_compress=do_compress,
+                laz_backend=laz_backend,
+                closefd=closefd,
+                encoding_errors=encoding_errors,
+            )
+        except:
+            if closefd:
+                stream.close()
+            raise
     elif mode == "a":
         if isinstance(source, (str, Path)):
             stream = open(source, mode="rb+", closefd=closefd)
@@ -179,13 +190,18 @@ def open_las(
             stream = io.BytesIO(source)
         else:
             stream = source
-        return LasAppender(
-            stream,
-            closefd=closefd,
-            laz_backend=laz_backend,
-            encoding_errors=encoding_errors,
-        )
 
+        try:
+            return LasAppender(
+                stream,
+                closefd=closefd,
+                laz_backend=laz_backend,
+                encoding_errors=encoding_errors,
+            )
+        except:
+            if closefd:
+                stream.close()
+            raise
     else:
         raise ValueError(f"Unknown mode '{mode}'")
 
