@@ -1,8 +1,9 @@
-""" The definition of the VLR Header, VLR, the KnownVLRs
- are in this module.
+"""The definition of the VLR Header, VLR, the KnownVLRs
+are in this module.
 
- A KnownVLR is a VLR for which we know how to parse its record_data
+A KnownVLR is a VLR for which we know how to parse its record_data
 """
+
 import abc
 import ctypes
 import logging
@@ -402,10 +403,8 @@ class WaveformPacketVlr(BaseKnownVLR):
 
     @classmethod
     def from_raw(cls, raw_vlr):
-        vlr = cls(
-            raw_vlr.header.record_id, description=raw_vlr.header.description.decode()
-        )
-        vlr.description = raw_vlr.header.description
+        vlr = cls(raw_vlr.record_id, description=raw_vlr.description)
+        vlr._description = raw_vlr.description
         vlr.parse_record_data(raw_vlr.record_data)
         return vlr
 
@@ -664,6 +663,9 @@ class WktCoordinateSystemVlr(BaseKnownVLR):
     def parse_crs(self):
         import pyproj
 
+        if not self.string:
+            return None
+
         return pyproj.CRS.from_wkt(self.string)
 
     @staticmethod
